@@ -101,3 +101,31 @@ def clear():
 
 def jq_tmpl(id):
     return tf.SCRIPT(id=id, type="text/x-jquery-tmpl")
+
+class VForm(object):
+    def __init__(self, classes=[], **attrs):
+        self.classes = classes
+        self.attrs = attrs
+        self.fields = []
+        self.btns = []
+    def add_field(self, label, input, fhelp=None):
+        label = label + ' *' if 'required' in input.nv_attributes else label
+        field_box = tf.DIV(Class="vform-field", For=input.attributes['id'])
+        field_box.label_box = tf.DIV()
+        field_box.label_box.label = tf.LABEL(label, Class='vform-label')
+        field_box.input = input
+        input.add_classes(['vform-input'])
+        if fhelp:
+            field_box.fhelp = tf.SPAN(fhelp, Class='vform-inp-help')
+        self.fields.append(field_box)
+    def add_buttons(self, *btns):
+        self.btns = btns
+    def build(self):
+        form = tf.FORM(**self.attrs)
+        form.add_classes(['vform'] + self.classes)
+        form.fields = self.fields
+        if self.btns:
+            buttons = tf.DIV(Class='buttons')
+            buttons.btns = self.btns
+            form.buttons = buttons
+        return form
